@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -147,11 +147,10 @@ int QmlJSIndenter::columnForIndex(const QString &t, int index) const
         index = t.length();
 
     for (int i = 0; i < index; i++) {
-        if (t.at(i) == QLatin1Char('\t')) {
+        if (t.at(i) == QLatin1Char('\t'))
             col = ((col / ppHardwareTabSize) + 1) * ppHardwareTabSize;
-        } else {
+        else
             col++;
-        }
     }
     return col;
 }
@@ -186,10 +185,10 @@ QChar QmlJSIndenter::lastParen() const
         const Token &token = yyLinizerState.tokens.at(index);
 
         if (token.is(Token::LeftParenthesis))
-            return QChar('(');
+            return QLatin1Char('(');
 
         else if (token.is(Token::RightParenthesis))
-            return QChar(')');
+            return QLatin1Char(')');
     }
 
     return QChar();
@@ -288,11 +287,10 @@ int QmlJSIndenter::indentForContinuationLine()
                     delimiters.
                 */
                 if (braceDepth == -1) {
-                    if (j < yyLine->length() - 1) {
+                    if (j < yyLine->length() - 1)
                         hook = j;
-                    } else {
+                    else
                         return 0; // shouldn't happen
-                    }
                 }
                 break;
             case '=':
@@ -324,7 +322,7 @@ int QmlJSIndenter::indentForContinuationLine()
                 Q_ASSERT(j - 1 >= 0);
 
                 if (QString::fromLatin1("!=<>").indexOf(yyLine->at(j - 1)) == -1 &&
-                     j + 1 < yyLine->length() && yyLine->at(j + 1) != '=') {
+                     j + 1 < yyLine->length() && yyLine->at(j + 1) != QLatin1Char('=')) {
                     if (braceDepth == 0 && delimDepth == 0 &&
                          j < yyLine->length() - 1 &&
                          !yyLine->endsWith(QLatin1Char(',')) &&
@@ -587,17 +585,15 @@ int QmlJSIndenter::indentForBottomLine(QTextBlock begin, QTextBlock end, QChar t
             smartly, unless the user has already played around with it,
             in which case it's better to leave her stuff alone.
         */
-        if (isOnlyWhiteSpace(bottomLine)) {
+        if (isOnlyWhiteSpace(bottomLine))
             indent = indentWhenBottomLineStartsInMultiLineComment();
-        } else {
+        else
             indent = indentOfLine(bottomLine);
-        }
     } else {
-        if (isUnfinishedLine()) {
+        if (isUnfinishedLine())
             indent = indentForContinuationLine();
-        } else {
+        else
             indent = indentForStandaloneLine();
-        }
 
         if ((okay(typedIn, QLatin1Char('}')) && firstCh == QLatin1Char('}'))
             || (okay(typedIn, QLatin1Char(']')) && firstCh == QLatin1Char(']'))) {
