@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef FILEUTILS_H
 #define FILEUTILS_H
@@ -52,14 +49,53 @@ QT_END_NAMESPACE
 
 namespace Utils {
 
+class QTCREATOR_UTILS_EXPORT FileName : private QString
+{
+public:
+    FileName();
+    explicit FileName(const QFileInfo &info);
+    QFileInfo toFileInfo() const;
+    static FileName fromString(const QString &filename);
+    static FileName fromUserInput(const QString &filename);
+    QString toString() const;
+    QString toUserOutput() const;
+
+    FileName parentDir() const;
+
+    bool operator==(const FileName &other) const;
+    bool operator!=(const FileName &other) const;
+    bool operator<(const FileName &other) const;
+    bool operator<=(const FileName &other) const;
+    bool operator>(const FileName &other) const;
+    bool operator>=(const FileName &other) const;
+
+    bool isChildOf(const FileName &s) const;
+    bool isChildOf(const QDir &dir) const;
+    bool endsWith(const QString &s) const;
+
+    Utils::FileName relativeChildPath(const FileName &parent) const;
+    Utils::FileName &appendPath(const QString &s);
+    Utils::FileName &append(const QString &str);
+    Utils::FileName &append(QChar str);
+
+    using QString::size;
+    using QString::count;
+    using QString::length;
+    using QString::isEmpty;
+    using QString::isNull;
+    using QString::clear;
+private:
+    FileName(const QString &string);
+};
+
 class QTCREATOR_UTILS_EXPORT FileUtils {
 public:
-    static bool removeRecursively(const QString &filePath, QString *error = 0);
-    static bool copyRecursively(const QString &srcFilePath,
-                         const QString &tgtFilePath, QString *error = 0);
-    static bool isFileNewerThan(const QString &filePath,
-                            const QDateTime &timeStamp);
-    static QString resolveSymlinks(const QString &path);
+    static bool removeRecursively(const FileName &filePath, QString *error = 0);
+    static bool copyRecursively(const FileName &srcFilePath, const FileName &tgtFilePath,
+                                QString *error = 0);
+    static bool isFileNewerThan(const FileName &filePath, const QDateTime &timeStamp);
+    static FileName resolveSymlinks(const FileName &path);
+    static QString shortNativePath(const FileName &path);
 };
 
 class QTCREATOR_UTILS_EXPORT FileReader
@@ -141,45 +177,6 @@ private:
     bool m_autoRemove;
 };
 
-class QTCREATOR_UTILS_EXPORT FileName : private QString
-{
-public:
-    FileName();
-    explicit FileName(const QFileInfo &info);
-    QFileInfo toFileInfo() const;
-    static FileName fromString(const QString &filename);
-    static FileName fromUserInput(const QString &filename);
-    QString toString() const;
-    QString toUserOutput() const;
-
-    FileName parentDir() const;
-
-    bool operator==(const FileName &other) const;
-    bool operator!=(const FileName &other) const;
-    bool operator<(const FileName &other) const;
-    bool operator<=(const FileName &other) const;
-    bool operator>(const FileName &other) const;
-    bool operator>=(const FileName &other) const;
-
-    bool isChildOf(const FileName &s) const;
-    bool endsWith(const QString &s) const;
-
-    Utils::FileName relativeChildPath(const FileName &parent) const;
-    Utils::FileName &appendPath(const QString &s);
-    Utils::FileName &append(const QString &str);
-    Utils::FileName &append(QChar str);
-
-    using QString::size;
-    using QString::count;
-    using QString::length;
-    using QString::isEmpty;
-    using QString::isNull;
-    using QString::clear;
-private:
-    static Qt::CaseSensitivity cs;
-    FileName(const QString &string);
-};
-
 } // namespace Utils
 
 QT_BEGIN_NAMESPACE
