@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "debuggerengine.h"
 
@@ -50,7 +47,6 @@
 #include "stackhandler.h"
 #include "threadshandler.h"
 #include "watchhandler.h"
-#include "qtmessageloghandler.h"
 
 #include <coreplugin/icore.h>
 #include <coreplugin/idocument.h>
@@ -61,13 +57,15 @@
 #include <texteditor/itexteditor.h>
 #include <texteditor/basetextmark.h>
 
+#include <projectexplorer/projectexplorer.h>
 #include <projectexplorer/taskhub.h>
-#include <extensionsystem/pluginmanager.h>
 
 #include <utils/savedaction.h>
 #include <utils/qtcassert.h>
 #include <utils/fileinprojectfinder.h>
 
+#include <qmljs/consolemanagerinterface.h>
+
 #include <QDebug>
 #include <QTimer>
 #include <QFile>
@@ -86,6 +84,10 @@ enum { debug = 0 };
 #define SDEBUG(s) if (!debug) {} else qDebug() << s;
 #define XSDEBUG(s) qDebug() << s
 
+//#define WITH_BENCHMARK
+#ifdef WITH_BENCHMARK
+#include <valgrind/callgrind.h>
+#endif
 
 ///////////////////////////////////////////////////////////////////////
 //
@@ -124,9 +126,7 @@ QDebug operator<<(QDebug str, const DebuggerStartParameters &sp)
             << " attachPID=" << sp.attachPID
             << " useTerminal=" << sp.useTerminal
             << " remoteChannel=" << sp.remoteChannel
-            << " remoteArchitecture=" << sp.remoteArchitecture
             << " symbolFileName=" << sp.symbolFileName
-            << " useServerStartScript=" << sp.useServerStartScript
             << " serverStartScript=" << sp.serverStartScript
             << " abi=" << sp.toolChainAbi.toString() << '\n';
     return str;
@@ -153,21 +153,17 @@ class DebuggerEnginePrivate : public QObject
     Q_OBJECT
 
 public:
-    DebuggerEnginePrivate(DebuggerEngine *engine,
-            DebuggerEngine *masterEngine,
-            DebuggerLanguages languages,
-            const DebuggerStartParameters &sp)
+    DebuggerEnginePrivate(DebuggerEngine *engine, const DebuggerStartParameters &sp)
       : m_engine(engine),
-        m_masterEngine(masterEngine),
+        m_masterEngine(0),
         m_runControl(0),
         m_startParameters(sp),
-        m_languages(languages),
         m_state(DebuggerNotReady),
         m_lastGoodState(DebuggerNotReady),
         m_targetState(DebuggerNotReady),
         m_remoteSetupState(RemoteSetupNone),
         m_inferiorPid(0),
-        m_modulesHandler(),
+        m_modulesHandler(engine),
         m_registerHandler(),
         m_sourceFilesHandler(),
         m_stackHandler(),
@@ -181,12 +177,8 @@ public:
         m_taskHub(0)
     {
         connect(&m_locationTimer, SIGNAL(timeout()), SLOT(resetLocation()));
-        if (sp.toolChainAbi.os() == Abi::MacOS)
-            m_disassemblerAgent.setTryMixed(false);
     }
 
-    ~DebuggerEnginePrivate() {}
-
 public slots:
     void doSetupEngine();
     void doSetupInferior();
@@ -269,6 +261,8 @@ public slots:
         m_disassemblerAgent.resetLocation();
     }
 
+    TaskHub *taskHub();
+
 public:
     DebuggerState state() const { return m_state; }
     RemoteSetupState remoteSetupState() const { return m_remoteSetupState; }
@@ -282,7 +276,6 @@ public:
     DebuggerRunControl *m_runControl;  // Not owned.
 
     DebuggerStartParameters m_startParameters;
-    DebuggerLanguages m_languages;
 
     // The current state.
     DebuggerState m_state;
@@ -304,7 +297,6 @@ public:
     StackHandler m_stackHandler;
     ThreadsHandler m_threadsHandler;
     WatchHandler m_watchHandler;
-    QtMessageLogHandler m_qtMessageHandler;
     QFutureInterface<void> m_progress;
 
     DisassemblerAgent m_disassemblerAgent;
@@ -335,13 +327,9 @@ public:
 //
 //////////////////////////////////////////////////////////////////////
 
-DebuggerEngine::DebuggerEngine(const DebuggerStartParameters &startParameters,
-        DebuggerLanguages languages,
-        DebuggerEngine *parentEngine)
-  : d(new DebuggerEnginePrivate(this, parentEngine, languages, startParameters))
-{
-    d->m_inferiorPid = 0;
-}
+DebuggerEngine::DebuggerEngine(const DebuggerStartParameters &startParameters)
+  : d(new DebuggerEnginePrivate(this, startParameters))
+{}
 
 DebuggerEngine::~DebuggerEngine()
 {
@@ -439,11 +427,6 @@ WatchHandler *DebuggerEngine::watchHandler() const
         : &d->m_watchHandler;
 }
 
-QtMessageLogHandler *DebuggerEngine::qtMessageLogHandler() const
-{
-    return &d->m_qtMessageHandler;
-}
-
 SourceFilesHandler *DebuggerEngine::sourceFilesHandler() const
 {
     return d->m_masterEngine
@@ -485,34 +468,32 @@ QAbstractItemModel *DebuggerEngine::threadsModel() const
 
 QAbstractItemModel *DebuggerEngine::localsModel() const
 {
-    QAbstractItemModel *model = watchHandler()->model(LocalsWatch);
-    if (model->objectName().isEmpty()) // Make debugging easier.
-        model->setObjectName(objectName() + QLatin1String("LocalsModel"));
-    return model;
+    return watchHandler()->model();
 }
 
 QAbstractItemModel *DebuggerEngine::watchersModel() const
 {
-    QAbstractItemModel *model = watchHandler()->model(WatchersWatch);
-    if (model->objectName().isEmpty()) // Make debugging easier.
-        model->setObjectName(objectName() + QLatin1String("WatchersModel"));
-    return model;
+    return watchHandler()->model();
 }
 
 QAbstractItemModel *DebuggerEngine::returnModel() const
 {
-    QAbstractItemModel *model = watchHandler()->model(ReturnWatch);
-    if (model->objectName().isEmpty()) // Make debugging easier.
-        model->setObjectName(objectName() + QLatin1String("ReturnModel"));
-    return model;
+    return watchHandler()->model();
+}
+
+QAbstractItemModel *DebuggerEngine::inspectorModel() const
+{
+    return watchHandler()->model();
 }
 
 QAbstractItemModel *DebuggerEngine::toolTipsModel() const
 {
-    QAbstractItemModel *model = watchHandler()->model(TooltipsWatch);
-    if (model->objectName().isEmpty()) // Make debugging easier.
-        model->setObjectName(objectName() + QLatin1String("TooltipsModel"));
-    return model;
+    return watchHandler()->model();
+}
+
+QAbstractItemModel *DebuggerEngine::watchModel() const
+{
+    return watchHandler()->model();
 }
 
 QAbstractItemModel *DebuggerEngine::sourceFilesModel() const
@@ -523,14 +504,6 @@ QAbstractItemModel *DebuggerEngine::sourceFilesModel() const
     return model;
 }
 
-QAbstractItemModel *DebuggerEngine::qtMessageLogModel() const
-{
-    QAbstractItemModel *model = qtMessageLogHandler()->model();
-    if (model->objectName().isEmpty()) // Make debugging easier.
-        model->setObjectName(objectName() + QLatin1String("QtMessageLogModel"));
-    return model;
-}
-
 void DebuggerEngine::fetchMemory(MemoryAgent *, QObject *,
         quint64 addr, quint64 length)
 {
@@ -559,15 +532,15 @@ void DebuggerEngine::showMessage(const QString &msg, int channel, int timeout) c
     }
     //if (msg.size() && msg.at(0).isUpper() && msg.at(1).isUpper())
     //    qDebug() << qPrintable(msg) << "IN STATE" << state();
-    if (channel == QtMessageLogOutput)
-        qtMessageLogHandler()->appendMessage(QtMessageLogHandler::UndefinedType, msg);
+    QmlJS::ConsoleManagerInterface *consoleManager = QmlJS::ConsoleManagerInterface::instance();
+    if (channel == ConsoleOutput && consoleManager)
+        consoleManager->printToConsolePane(QmlJS::ConsoleItem::UndefinedType, msg);
 
     debuggerCore()->showMessage(msg, channel, timeout);
-    if (d->m_runControl) {
+    if (d->m_runControl)
         d->m_runControl->showMessage(msg, channel);
-    } else {
+    else
         qWarning("Warning: %s (no active run control)", qPrintable(msg));
-    }
 }
 
 void DebuggerEngine::startDebugger(DebuggerRunControl *runControl)
@@ -613,7 +586,8 @@ void DebuggerEngine::gotoLocation(const Location &loc)
 {
      d->resetLocation();
 
-    if (debuggerCore()->boolSetting(OperateByInstruction) || !loc.hasDebugInfo()) {
+    if ((hasCapability(OperateByInstructionCapability) &&
+            debuggerCore()->boolSetting(OperateByInstruction)) || !loc.hasDebugInfo()) {
         d->m_disassemblerAgent.setLocation(loc);
         return;
     }
@@ -624,11 +598,10 @@ void DebuggerEngine::gotoLocation(const Location &loc)
 
     const QString file = loc.fileName();
     const int line = loc.lineNumber();
-    EditorManager *editorManager = EditorManager::instance();
-    QList<IEditor *> editors = editorManager->editorsForFileName(file);
+    QList<IEditor *> editors = EditorManager::instance()->editorsForFileName(file);
     IEditor *editor = 0;
     if (editors.isEmpty()) {
-        editor = editorManager->openEditor(file, Core::Id(),
+        editor = EditorManager::openEditor(file, Core::Id(),
             EditorManager::IgnoreNavigationHistory);
         if (editor) {
             editors.append(editor);
@@ -650,7 +623,7 @@ void DebuggerEngine::gotoLocation(const Location &loc)
 
     // FIXME: Breaks with split views.
     if (!d->m_memoryAgent.hasVisibleEditor() || loc.needsRaise())
-        editorManager->activateEditor(editor);
+        EditorManager::activateEditor(editor);
     //qDebug() << "MEMORY: " << d->m_memoryAgent.hasVisibleEditor();
 }
 
@@ -687,36 +660,6 @@ DebuggerStartParameters &DebuggerEngine::startParameters()
     return d->m_startParameters;
 }
 
-
-//////////////////////////////////////////////////////////////////////
-//
-// Dumpers. "Custom dumpers" are a library compiled against the current
-// Qt containing functions to evaluate values of Qt classes
-// (such as QString, taking pointers to their addresses).
-// The library must be loaded into the debuggee.
-//
-//////////////////////////////////////////////////////////////////////
-
-bool DebuggerEngine::qtDumperLibraryEnabled() const
-{
-    return debuggerCore()->boolSetting(UseDebuggingHelpers);
-}
-
-QStringList DebuggerEngine::qtDumperLibraryLocations() const
-{
-    return d->m_startParameters.dumperLibraryLocations;
-}
-
-void DebuggerEngine::showQtDumperLibraryWarning(const QString &details)
-{
-    debuggerCore()->showQtDumperLibraryWarning(details);
-}
-
-QString DebuggerEngine::qtDumperLibraryName() const
-{
-    return startParameters().dumperLibrary;
-}
-
 DebuggerState DebuggerEngine::state() const
 {
     return d->m_state;
@@ -756,6 +699,7 @@ static bool isAllowedTransition(DebuggerState from, DebuggerState to)
 
     case EngineRunRequested:
         return to == EngineRunFailed
+            || to == InferiorRunRequested
             || to == InferiorRunOk
             || to == InferiorStopOk
             || to == InferiorUnrunnable;
@@ -876,6 +820,9 @@ void DebuggerEngine::notifyInferiorSetupFailed()
 
 void DebuggerEngine::notifyInferiorSetupOk()
 {
+#ifdef WITH_BENCHMARK
+    CALLGRIND_START_INSTRUMENTATION;
+#endif
     showMessage(_("NOTE: INFERIOR SETUP OK"));
     QTC_ASSERT(state() == InferiorSetupRequested, qDebug() << this << state());
     setState(InferiorSetupOk);
@@ -932,9 +879,15 @@ void DebuggerEngine::notifyEngineRequestRemoteSetup()
     emit requestRemoteSetup();
 }
 
-void DebuggerEngine::notifyEngineRemoteSetupDone()
+void DebuggerEngine::notifyEngineRemoteServerRunning(const QByteArray &, int /*pid*/)
 {
-    showMessage(_("NOTE: REMOTE SETUP DONE"));
+    showMessage(_("NOTE: REMOTE SERVER RUNNING IN MULTIMODE"));
+}
+
+void DebuggerEngine::notifyEngineRemoteSetupDone(int gdbServerPort, int qmlPort)
+{
+    showMessage(_("NOTE: REMOTE SETUP DONE: GDB SERVER PORT: %1  QML PORT %2")
+                .arg(gdbServerPort).arg(qmlPort));
     QTC_ASSERT(state() == EngineSetupRequested
                || state() == EngineSetupFailed
                || state() == DebuggerFinished, qDebug() << this << state());
@@ -949,9 +902,9 @@ void DebuggerEngine::notifyEngineRemoteSetupDone()
     d->setRemoteSetupState(RemoteSetupSucceeded);
 }
 
-void DebuggerEngine::notifyEngineRemoteSetupFailed()
+void DebuggerEngine::notifyEngineRemoteSetupFailed(const QString &message)
 {
-    showMessage(_("NOTE: REMOTE SETUP FAILED"));
+    showMessage(_("NOTE: REMOTE SETUP FAILED: ") + message);
     QTC_ASSERT(state() == EngineSetupRequested
                || state() == EngineSetupFailed
                || state() == DebuggerFinished, qDebug() << this << state());
@@ -961,6 +914,16 @@ void DebuggerEngine::notifyEngineRemoteSetupFailed()
                qDebug() << this << "remoteSetupState" << d->remoteSetupState());
 }
 
+void DebuggerEngine::notifyEngineRunOkAndInferiorRunRequested()
+{
+    showMessage(_("NOTE: ENGINE RUN OK AND INFERIOR RUN REQUESTED"));
+    d->m_progress.setProgressValue(1000);
+    d->m_progress.reportFinished();
+    QTC_ASSERT(state() == EngineRunRequested, qDebug() << this << state());
+    showStatusMessage(tr("Running."));
+    setState(InferiorRunRequested);
+}
+
 void DebuggerEngine::notifyEngineRunAndInferiorRunOk()
 {
     showMessage(_("NOTE: ENGINE RUN AND INFERIOR RUN OK"));
@@ -991,10 +954,15 @@ void DebuggerEngine::notifyInferiorRunRequested()
 
 void DebuggerEngine::notifyInferiorRunOk()
 {
+    if (state() == InferiorRunOk) {
+        showMessage(_("NOTE: INFERIOR RUN OK - REPEATED."));
+        return;
+    }
     showMessage(_("NOTE: INFERIOR RUN OK"));
     showStatusMessage(tr("Running."));
-    // Transition from StopRequested can happen sin remotegdbadapter.
+    // Transition from StopRequested can happen in remotegdbadapter.
     QTC_ASSERT(state() == InferiorRunRequested
+        || state() == InferiorStopOk
         || state() == InferiorStopRequested, qDebug() << this << state());
     setState(InferiorRunOk);
 }
@@ -1022,9 +990,8 @@ void DebuggerEngine::notifyInferiorStopOk()
             showMessage(_("NOTE: ... FORWARDING TO 'STOP OK'. "));
             setState(InferiorStopOk);
         }
-        if (state() == InferiorStopOk || state() == InferiorStopFailed) {
+        if (state() == InferiorStopOk || state() == InferiorStopFailed)
             d->queueShutdownInferior();
-        }
         showMessage(_("NOTE: ... IGNORING STOP MESSAGE"));
         return;
     }
@@ -1039,6 +1006,8 @@ void DebuggerEngine::notifyInferiorSpontaneousStop()
     QTC_ASSERT(state() == InferiorRunOk, qDebug() << this << state());
     showStatusMessage(tr("Stopped."));
     setState(InferiorStopOk);
+    if (debuggerCore()->boolSetting(RaiseOnInterrupt))
+        emit raiseWindow();
 }
 
 void DebuggerEngine::notifyInferiorStopFailed()
@@ -1169,6 +1138,10 @@ void DebuggerEnginePrivate::setRemoteSetupState(RemoteSetupState state)
 
 void DebuggerEngine::notifyEngineIll()
 {
+#ifdef WITH_BENCHMARK
+    CALLGRIND_STOP_INSTRUMENTATION;
+    CALLGRIND_DUMP_STATS;
+#endif
     showMessage(_("NOTE: ENGINE ILL ******"));
     d->m_targetState = DebuggerFinished;
     d->m_lastGoodState = d->m_state;
@@ -1198,6 +1171,10 @@ void DebuggerEngine::notifyEngineIll()
 
 void DebuggerEngine::notifyEngineSpontaneousShutdown()
 {
+#ifdef WITH_BENCHMARK
+    CALLGRIND_STOP_INSTRUMENTATION;
+    CALLGRIND_DUMP_STATS;
+#endif
     showMessage(_("NOTE: ENGINE SPONTANEOUS SHUTDOWN"));
     setState(EngineShutdownOk, true);
     if (isMasterEngine())
@@ -1206,6 +1183,10 @@ void DebuggerEngine::notifyEngineSpontaneousShutdown()
 
 void DebuggerEngine::notifyInferiorExited()
 {
+#ifdef WITH_BENCHMARK
+    CALLGRIND_STOP_INSTRUMENTATION;
+    CALLGRIND_DUMP_STATS;
+#endif
     showMessage(_("NOTE: INFERIOR EXITED"));
     d->resetLocation();
     setState(InferiorExitOk);
@@ -1255,10 +1236,6 @@ void DebuggerEngine::setState(DebuggerState state, bool forced)
             handler->notifyBreakpointReleased(id);
     }
 
-    const bool running = d->m_state == InferiorRunOk;
-    if (running)
-        threadsHandler()->notifyRunning();
-
     showMessage(msg, LogDebug);
     updateViews();
 
@@ -1286,22 +1263,23 @@ bool DebuggerEngine::isMasterEngine() const
     return d->m_masterEngine == 0;
 }
 
+void DebuggerEngine::setMasterEngine(DebuggerEngine *masterEngine)
+{
+    d->m_masterEngine = masterEngine;
+}
+
 DebuggerEngine *DebuggerEngine::masterEngine() const
 {
     return d->m_masterEngine;
 }
 
-DebuggerLanguages DebuggerEngine::languages() const
-{
-    return d->m_languages;
-}
-
 QString DebuggerEngine::toFileInProject(const QUrl &fileUrl)
 {
     // make sure file finder is properly initialized
-    d->m_fileFinder.setProjectDirectory(startParameters().projectSourceDirectory);
-    d->m_fileFinder.setProjectFiles(startParameters().projectSourceFiles);
-    d->m_fileFinder.setSysroot(startParameters().sysroot);
+    const DebuggerStartParameters &sp = startParameters();
+    d->m_fileFinder.setProjectDirectory(sp.projectSourceDirectory);
+    d->m_fileFinder.setProjectFiles(sp.projectSourceFiles);
+    d->m_fileFinder.setSysroot(sp.sysRoot);
 
     return d->m_fileFinder.findFile(fileUrl);
 }
@@ -1395,6 +1373,8 @@ void DebuggerEngine::quitDebugger()
         break;
     case EngineRunFailed:
     case DebuggerFinished:
+    case InferiorExitOk:
+    case InferiorShutdownOk:
         break;
     case InferiorSetupRequested:
         notifyInferiorSetupFailed();
@@ -1438,6 +1418,10 @@ void DebuggerEngine::updateWatchData(const WatchData &, const WatchUpdateFlags &
 {
 }
 
+void DebuggerEngine::watchDataSelected(const QByteArray &)
+{
+}
+
 void DebuggerEngine::watchPoint(const QPoint &)
 {
 }
@@ -1474,6 +1458,10 @@ void DebuggerEngine::requestModuleSymbols(const QString &)
 {
 }
 
+void DebuggerEngine::requestModuleSections(const QString &)
+{
+}
+
 void DebuggerEngine::reloadRegisters()
 {
 }
@@ -1486,6 +1474,10 @@ void DebuggerEngine::reloadFullStack()
 {
 }
 
+void DebuggerEngine::reloadDebuggingHelpers()
+{
+}
+
 void DebuggerEngine::addOptionPages(QList<Core::IOptionsPage*> *) const
 {
 }
@@ -1519,6 +1511,7 @@ void DebuggerEngine::updateAll()
 
 void DebuggerEngine::attemptBreakpointSynchronization()
 {
+    showMessage(_("ATTEMPT BREAKPOINT SYNCHRONIZATION"));
     if (!stateAcceptsBreakpointChanges()) {
         showMessage(_("BREAKPOINT SYNCHRONIZATION NOT POSSIBLE IN CURRENT STATE"));
         return;
@@ -1528,8 +1521,14 @@ void DebuggerEngine::attemptBreakpointSynchronization()
 
     foreach (BreakpointModelId id, handler->unclaimedBreakpointIds()) {
         // Take ownership of the breakpoint. Requests insertion.
-        if (acceptsBreakpoint(id))
+        if (acceptsBreakpoint(id)) {
+            showMessage(_("TAKING OWNERSHIP OF BREAKPOINT %1 IN STATE %2")
+                .arg(id.toString()).arg(handler->state(id)));
             handler->setEngine(id, this);
+        } else {
+            showMessage(_("BREAKPOINT %1 IN STATE %2 IS NOT ACCEPTABLE")
+                .arg(id.toString()).arg(handler->state(id)));
+        }
     }
 
     bool done = true;
@@ -1569,8 +1568,12 @@ void DebuggerEngine::attemptBreakpointSynchronization()
         QTC_ASSERT(false, qDebug() << "UNKNOWN STATE"  << id << state());
     }
 
-    if (done)
+    if (done) {
+        showMessage(_("BREAKPOINTS ARE SYNCHRONIZED"));
         d->m_disassemblerAgent.updateBreakpointMarkers();
+    } else {
+        showMessage(_("BREAKPOINTS ARE NOT FULLY SYNCHRONIZED"));
+    }
 }
 
 void DebuggerEngine::insertBreakpoint(BreakpointModelId id)
@@ -1594,10 +1597,6 @@ void DebuggerEngine::changeBreakpoint(BreakpointModelId id)
     QTC_CHECK(false);
 }
 
-void DebuggerEngine::selectThread(int)
-{
-}
-
 void DebuggerEngine::assignValueInDebugger(const WatchData *,
     const QString &, const QVariant &)
 {
@@ -1658,17 +1657,11 @@ void DebuggerEngine::executeJumpToLine(const ContextData &)
 {
 }
 
-void DebuggerEngine::executeDebuggerCommand(const QString &)
+void DebuggerEngine::executeDebuggerCommand(const QString &, DebuggerLanguages)
 {
     showStatusMessage(tr("This debugger cannot handle user input."));
 }
 
-bool DebuggerEngine::evaluateScriptExpression(const QString &)
-{
-    showStatusMessage(tr("This debugger cannot handle user input."));
-    return false;
-}
-
 BreakHandler *DebuggerEngine::breakHandler() const
 {
     return debuggerCore()->breakHandler();
@@ -1791,15 +1784,6 @@ void DebuggerEngine::openDisassemblerView(const Location &location)
     agent->setLocation(location);
 }
 
-void DebuggerEngine::handleRemoteSetupDone(int /*gdbServerPort*/,
-                                           int /*qmlPort*/)
-{
-}
-
-void DebuggerEngine::handleRemoteSetupFailed(const QString &/*message*/)
-{
-}
-
 bool DebuggerEngine::isStateDebugging() const
 {
     return d->m_isStateDebugging;
@@ -1952,15 +1936,27 @@ void DebuggerEnginePrivate::reportTestError(const QString &msg, int line)
 {
     m_engine->showMessage(_("### Line %1: %2").arg(line).arg(msg));
     m_foundError = true;
-
-    if (!m_taskHub) {
-        ExtensionSystem::PluginManager *pm = ExtensionSystem::PluginManager::instance();
-        m_taskHub = pm->getObject<TaskHub>();
-        m_taskHub->addCategory(Core::Id("DebuggerTest"), tr("Debugger Test"));
-    }
-
     Task task(Task::Error, msg, Utils::FileName::fromUserInput(m_testFileName), line + 1, Core::Id("DebuggerTest"));
-    m_taskHub->addTask(task);
+    taskHub()->addTask(task);
+}
+
+TaskHub *DebuggerEnginePrivate::taskHub()
+{
+    if (!m_taskHub) {
+        m_taskHub = ProjectExplorerPlugin::instance()->taskHub();
+        m_taskHub->addCategory(Core::Id(Debugger::Constants::TASK_CATEGORY_DEBUGGER_DEBUGINFO),
+                               tr("Debug Information"));
+        m_taskHub->addCategory(Core::Id(Debugger::Constants::TASK_CATEGORY_DEBUGGER_TEST),
+                               tr("Debugger Test"));
+        m_taskHub->addCategory(Core::Id(Debugger::Constants::TASK_CATEGORY_DEBUGGER_RUNTIME),
+                               tr("Debugger Runtime"));
+    }
+    return m_taskHub;
+}
+
+TaskHub *DebuggerEngine::taskHub()
+{
+    return d->taskHub();
 }
 
 } // namespace Debugger
