@@ -1,44 +1,41 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "abi.h"
 
-#include <QtCore/QCoreApplication>
-#include <QtCore/QDebug>
-#include <QtCore/QtEndian>
-#include <QtCore/QFile>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QSysInfo>
+#include <QCoreApplication>
+#include <QDebug>
+#include <QtEndian>
+#include <QFile>
+#include <QString>
+#include <QStringList>
+#include <QSysInfo>
 
 /*!
     \class ProjectExplorer::Abi
@@ -137,26 +134,32 @@ static QList<Abi> parseCoffHeader(const QByteArray &data)
         break;
     }
 
-    if (data.size() >= 68) {
+    if (data.size() >= 24) {
         // Get Major and Minor Image Version from optional header fields
-        quint32 image = getLEUint32(data, 64);
-        if (image == 1) { // Image is 1 for mingw and higher for MSVC (4.something in some encoding)
+        quint8 minorLinker = data.at(23);
+        switch (data.at(22)) {
+        case 2:
+        case 3: // not yet reached:-)
             flavor = Abi::WindowsMSysFlavor;
-        } else {
-            switch (data.at(22)) {
-            case 8:
-                flavor = Abi::WindowsMsvc2005Flavor;
-                break;
-            case 9:
-                flavor = Abi::WindowsMsvc2008Flavor;
-                break;
-            case 10:
-                flavor = Abi::WindowsMsvc2010Flavor;
-                break;
-            default:
-                // Keep unknown flavor
-                break;
-            }
+            break;
+        case 8:
+            flavor = Abi::WindowsMsvc2005Flavor;
+            break;
+        case 9:
+            flavor = Abi::WindowsMsvc2008Flavor;
+            break;
+        case 10:
+            flavor = Abi::WindowsMsvc2010Flavor;
+            break;
+        case 11:
+            flavor = Abi::WindowsMsvc2012Flavor;
+            break;
+        default: // Keep unknown flavor
+            if (minorLinker != 0)
+                flavor = Abi::WindowsMSysFlavor; // MSVC seems to avoid using minor numbers
+            else
+                qWarning("%s: Unknown MSVC flavour encountered.", Q_FUNC_INFO);
+            break;
         }
     }
 
@@ -190,6 +193,7 @@ static QList<Abi> abiOf(const QByteArray &data)
             break;
         case 3: // Linux:
         case 0: // no extra info available: Default to Linux:
+        case 97: // ARM, also linux most of the time.
             os = Abi::LinuxOS;
             flavor = Abi::GenericLinuxFlavor;
             break;
@@ -263,10 +267,6 @@ static QList<Abi> abiOf(const QByteArray &data)
             result.append(macAbiForCpu(type));
             pos += 20;
         }
-    } else if (data.size() >= 20
-               && getUint8(data, 16) == 'E' && getUint8(data, 17) == 'P'
-               && getUint8(data, 18) == 'O' && getUint8(data, 19) == 'C') {
-        result.append(Abi(Abi::ArmArchitecture, Abi::SymbianOS, Abi::SymbianDeviceFlavor, Abi::ElfFormat, 32));
     } else if (data.size() >= 64){
         // Windows PE: values are LE (except for a few exceptions which we will not use here).
 
@@ -300,7 +300,7 @@ Abi::Abi(const Architecture &a, const OS &o,
         m_osFlavor = UnknownFlavor;
         break;
     case ProjectExplorer::Abi::LinuxOS:
-        if (m_osFlavor < GenericLinuxFlavor || m_osFlavor > MeegoLinuxFlavor)
+        if (m_osFlavor < GenericLinuxFlavor || m_osFlavor > MaemoLinuxFlavor)
             m_osFlavor = UnknownFlavor;
         break;
     case ProjectExplorer::Abi::BsdOS:
@@ -310,10 +310,6 @@ Abi::Abi(const Architecture &a, const OS &o,
         if (m_osFlavor < GenericMacFlavor || m_osFlavor > GenericMacFlavor)
             m_osFlavor = UnknownFlavor;
         break;
-    case ProjectExplorer::Abi::SymbianOS:
-        if (m_osFlavor < SymbianDeviceFlavor || m_osFlavor > SymbianEmulatorFlavor)
-            m_osFlavor = UnknownFlavor;
-        break;
     case ProjectExplorer::Abi::UnixOS:
         if (m_osFlavor < GenericUnixFlavor || m_osFlavor > GenericUnixFlavor)
             m_osFlavor = UnknownFlavor;
@@ -358,8 +354,6 @@ Abi::Abi(const QString &abiString) :
             m_os = BsdOS;
         else if (abiParts.at(1) == QLatin1String("macos"))
             m_os = MacOS;
-        else if (abiParts.at(1) == QLatin1String("symbian"))
-            m_os = SymbianOS;
         else if (abiParts.at(1) == QLatin1String("unix"))
             m_os = UnixOS;
         else if (abiParts.at(1) == QLatin1String("windows"))
@@ -374,6 +368,8 @@ Abi::Abi(const QString &abiString) :
             m_osFlavor = UnknownFlavor;
         else if (abiParts.at(2) == QLatin1String("generic") && m_os == LinuxOS)
             m_osFlavor = GenericLinuxFlavor;
+        else if (abiParts.at(2) == QLatin1String("android") && m_os == LinuxOS)
+            m_osFlavor = AndroidLinuxFlavor;
         else if (abiParts.at(2) == QLatin1String("freebsd") && m_os == BsdOS)
             m_osFlavor = FreeBsdFlavor;
         else if (abiParts.at(2) == QLatin1String("netbsd") && m_os == BsdOS)
@@ -382,14 +378,10 @@ Abi::Abi(const QString &abiString) :
             m_osFlavor = OpenBsdFlavor;
         else if (abiParts.at(2) == QLatin1String("maemo") && m_os == LinuxOS)
             m_osFlavor = MaemoLinuxFlavor;
-        else if (abiParts.at(2) == QLatin1String("meego") && m_os == LinuxOS)
-            m_osFlavor = MeegoLinuxFlavor;
+        else if (abiParts.at(2) == QLatin1String("harmattan") && m_os == LinuxOS)
+            m_osFlavor = HarmattanLinuxFlavor;
         else if (abiParts.at(2) == QLatin1String("generic") && m_os == MacOS)
             m_osFlavor = GenericMacFlavor;
-        else if (abiParts.at(2) == QLatin1String("device") && m_os == SymbianOS)
-            m_osFlavor = SymbianDeviceFlavor;
-        else if (abiParts.at(2) == QLatin1String("emulator") && m_os == SymbianOS)
-            m_osFlavor = SymbianEmulatorFlavor;
         else if (abiParts.at(2) == QLatin1String("generic") && m_os == UnixOS)
             m_osFlavor = GenericUnixFlavor;
         else if (abiParts.at(2) == QLatin1String("solaris") && m_os == UnixOS)
@@ -400,6 +392,8 @@ Abi::Abi(const QString &abiString) :
             m_osFlavor = WindowsMsvc2008Flavor;
         else if (abiParts.at(2) == QLatin1String("msvc2010") && m_os == WindowsOS)
             m_osFlavor = WindowsMsvc2010Flavor;
+        else if (abiParts.at(2) == QLatin1String("msvc2012") && m_os == WindowsOS)
+            m_osFlavor = WindowsMsvc2012Flavor;
         else if (abiParts.at(2) == QLatin1String("msys") && m_os == WindowsOS)
             m_osFlavor = WindowsMSysFlavor;
         else if (abiParts.at(2) == QLatin1String("ce") && m_os == WindowsOS)
@@ -482,6 +476,8 @@ bool Abi::isCompatibleWith(const Abi &other) const
                   && (binaryFormat() == other.binaryFormat() || other.binaryFormat() == Abi::UnknownFormat)
                   && ((wordWidth() == other.wordWidth() && wordWidth() != 0) || other.wordWidth() == 0))
         isCompat = true;
+    if (osFlavor() == AndroidLinuxFlavor || other.osFlavor() == AndroidLinuxFlavor)
+        isCompat = (osFlavor() == other.osFlavor() && architecture() == other.architecture());
     return isCompat;
 }
 
@@ -533,8 +529,6 @@ QString Abi::toString(const OS &o)
         return QLatin1String("bsd");
     case MacOS:
         return QLatin1String("macos");
-    case SymbianOS:
-        return QLatin1String("symbian");
     case UnixOS:
         return QLatin1String("unix");
     case WindowsOS:
@@ -550,6 +544,8 @@ QString Abi::toString(const OSFlavor &of)
     switch (of) {
     case ProjectExplorer::Abi::GenericLinuxFlavor:
         return QLatin1String("generic");
+    case ProjectExplorer::Abi::AndroidLinuxFlavor:
+        return QLatin1String("android");
     case ProjectExplorer::Abi::FreeBsdFlavor:
         return QLatin1String("freebsd");
     case ProjectExplorer::Abi::NetBsdFlavor:
@@ -560,14 +556,8 @@ QString Abi::toString(const OSFlavor &of)
         return QLatin1String("maemo");
     case ProjectExplorer::Abi::HarmattanLinuxFlavor:
         return QLatin1String("harmattan");
-    case ProjectExplorer::Abi::MeegoLinuxFlavor:
-        return QLatin1String("meego");
     case ProjectExplorer::Abi::GenericMacFlavor:
         return QLatin1String("generic");
-    case ProjectExplorer::Abi::SymbianDeviceFlavor:
-        return QLatin1String("device");
-    case ProjectExplorer::Abi::SymbianEmulatorFlavor:
-        return QLatin1String("emulator");
     case ProjectExplorer::Abi::GenericUnixFlavor:
         return QLatin1String("generic");
     case ProjectExplorer::Abi::SolarisUnixFlavor:
@@ -578,6 +568,8 @@ QString Abi::toString(const OSFlavor &of)
         return QLatin1String("msvc2008");
     case ProjectExplorer::Abi::WindowsMsvc2010Flavor:
         return QLatin1String("msvc2010");
+    case ProjectExplorer::Abi::WindowsMsvc2012Flavor:
+        return QLatin1String("msvc2012");
     case ProjectExplorer::Abi::WindowsMSysFlavor:
         return QLatin1String("msys");
     case ProjectExplorer::Abi::WindowsCEFlavor:
@@ -617,18 +609,17 @@ QList<Abi::OSFlavor> Abi::flavorsForOs(const Abi::OS &o)
     QList<OSFlavor> result;
     switch (o) {
     case BsdOS:
-        return result << FreeBsdFlavor << OpenBsdFlavor << NetBsdFlavor;
+        return result << FreeBsdFlavor << OpenBsdFlavor << NetBsdFlavor << UnknownFlavor;
     case LinuxOS:
-        return result << GenericLinuxFlavor << HarmattanLinuxFlavor << MaemoLinuxFlavor << MeegoLinuxFlavor;
+        return result << GenericLinuxFlavor << HarmattanLinuxFlavor << MaemoLinuxFlavor
+                      << AndroidLinuxFlavor << UnknownFlavor;
     case MacOS:
-        return result << GenericMacFlavor;
-    case SymbianOS:
-        return  result << SymbianDeviceFlavor << SymbianEmulatorFlavor;
+        return result << GenericMacFlavor << UnknownFlavor;
     case UnixOS:
-        return result << GenericUnixFlavor << SolarisUnixFlavor;
+        return result << GenericUnixFlavor << SolarisUnixFlavor << UnknownFlavor;
     case WindowsOS:
         return result << WindowsMsvc2005Flavor << WindowsMsvc2008Flavor << WindowsMsvc2010Flavor
-                      << WindowsMSysFlavor << WindowsCEFlavor;
+                      << WindowsMsvc2012Flavor << WindowsMSysFlavor << WindowsCEFlavor << UnknownFlavor;
     case UnknownOS:
         return result << UnknownFlavor;
     default:
@@ -646,13 +637,15 @@ Abi Abi::hostAbi()
 
 #if defined (Q_OS_WIN)
     os = WindowsOS;
-#if _MSC_VER == 1600
+#if _MSC_VER == 1700
+    subos = WindowsMsvc2012Flavor;
+#elif _MSC_VER == 1600
     subos = WindowsMsvc2010Flavor;
 #elif _MSC_VER == 1500
     subos = WindowsMsvc2008Flavor;
 #elif _MSC_VER == 1400
     subos = WindowsMsvc2005Flavor;
-#elif defined (mingw32)
+#elif defined (Q_CC_MINGW)
     subos = WindowsMSysFlavor;
 #endif
     format = PEFormat;
@@ -666,20 +659,26 @@ Abi Abi::hostAbi()
     format = MachOFormat;
 #endif
 
-    return Abi(arch, os, subos, format, QSysInfo::WordSize);
+    const Abi result(arch, os, subos, format, QSysInfo::WordSize);
+    if (!result.isValid())
+        qWarning("Unable to completely determine the host ABI (%s).",
+                 qPrintable(result.toString()));
+    return result;
 }
 
-QList<Abi> Abi::abisOfBinary(const QString &path)
+QList<Abi> Abi::abisOfBinary(const Utils::FileName &path)
 {
     QList<Abi> tmp;
     if (path.isEmpty())
         return tmp;
 
-    QFile f(path);
+    QFile f(path.toString());
     if (!f.exists())
         return tmp;
 
-    f.open(QFile::ReadOnly);
+    if (!f.open(QFile::ReadOnly))
+        return tmp;
+
     QByteArray data = f.read(1024);
     if (data.size() >= 67
             && getUint8(data, 0) == '!' && getUint8(data, 1) == '<' && getUint8(data, 2) == 'a'
@@ -692,7 +691,7 @@ QList<Abi> Abi::abisOfBinary(const QString &path)
 
         while (!data.isEmpty()) {
             if ((getUint8(data, 58) != 0x60 || getUint8(data, 59) != 0x0a)) {
-                qWarning() << path << ": Thought it was an ar-file, but it is not!";
+                qWarning() << path.toString() << ": Thought it was an ar-file, but it is not!";
                 break;
             }
 
@@ -700,7 +699,7 @@ QList<Abi> Abi::abisOfBinary(const QString &path)
             quint64 fileNameOffset = 0;
             if (fileName.startsWith(QLatin1String("#1/")))
                 fileNameOffset = fileName.mid(3).toInt();
-            const QString fileLength = QString::fromAscii(data.mid(48, 10));
+            const QString fileLength = QString::fromLatin1(data.mid(48, 10));
 
             int toSkip = 60 + fileNameOffset;
             offset += fileLength.toInt() + 60 /* header */;
@@ -737,7 +736,7 @@ QList<Abi> Abi::abisOfBinary(const QString &path)
 // Unit tests:
 #ifdef WITH_TESTS
 #   include <QTest>
-#   include <QtCore/QFileInfo>
+#   include <QFileInfo>
 
 #   include "projectexplorer.h"
 
@@ -754,10 +753,10 @@ void ProjectExplorer::ProjectExplorerPlugin::testAbiOfBinary_data()
             << (QStringList());
 
     // Set up prefix for test data now that we can be sure to have some tests to run:
-    QString prefix = qgetenv("QTC_TEST_EXTRADATALOCATION");
+    QString prefix = QString::fromLocal8Bit(qgetenv("QTC_TEST_EXTRADATALOCATION"));
     if (prefix.isEmpty())
         return;
-    prefix += "/projectexplorer/abi";
+    prefix += QLatin1String("/projectexplorer/abi");
 
     QFileInfo fi(prefix);
     if (!fi.exists() || !fi.isDir())
@@ -796,9 +795,6 @@ void ProjectExplorer::ProjectExplorerPlugin::testAbiOfBinary_data()
                               << QString::fromLatin1("ppc-macos-generic-mach_o-32bit")
                               << QString::fromLatin1("x86-macos-generic-mach_o-64bit"));
 
-    QTest::newRow("dynamic QtCore: symbian")
-            << QString::fromLatin1("%1/dynamic/symbian.dll").arg(prefix)
-            << (QStringList() << QString::fromLatin1("arm-symbian-device-elf-32bit"));
     QTest::newRow("dynamic QtCore: win msvc2010 64bit")
             << QString::fromLatin1("%1/dynamic/win-msvc2010-64bit.dll").arg(prefix)
             << (QStringList() << QString::fromLatin1("x86-windows-msvc2010-pe-64bit"));
@@ -811,6 +807,9 @@ void ProjectExplorer::ProjectExplorerPlugin::testAbiOfBinary_data()
     QTest::newRow("dynamic QtCore: win msys 32bit")
             << QString::fromLatin1("%1/dynamic/win-mingw-32bit.dll").arg(prefix)
             << (QStringList() << QString::fromLatin1("x86-windows-msys-pe-32bit"));
+    QTest::newRow("dynamic QtCore: win mingw 64bit")
+            << QString::fromLatin1("%1/dynamic/win-mingw-64bit.dll").arg(prefix)
+            << (QStringList() << QString::fromLatin1("x86-windows-msys-pe-64bit"));
     QTest::newRow("dynamic QtCore: wince msvc2005 32bit")
             << QString::fromLatin1("%1/dynamic/wince-32bit.dll").arg(prefix)
             << (QStringList() << QString::fromLatin1("mips-windows-msvc2005-pe-32bit"));
@@ -822,6 +821,9 @@ void ProjectExplorer::ProjectExplorerPlugin::testAbiOfBinary_data()
     QTest::newRow("dynamic QtCore: arm linux 32bit")
             << QString::fromLatin1("%1/dynamic/arm-linux.so").arg(prefix)
             << (QStringList() << QString::fromLatin1("arm-linux-generic-elf-32bit"));
+    QTest::newRow("dynamic QtCore: arm linux 32bit, using ARM as OSABI")
+            << QString::fromLatin1("%1/dynamic/arm-linux2.so").arg(prefix)
+            << (QStringList() << QString::fromLatin1("arm-linux-generic-elf-32bit"));
     QTest::newRow("dynamic QtCore: arm linux 32bit (angstrom)")
             << QString::fromLatin1("%1/dynamic/arm-angstrom-linux.so").arg(prefix)
             << (QStringList() << QString::fromLatin1("arm-linux-generic-elf-32bit"));
@@ -857,7 +859,7 @@ void ProjectExplorer::ProjectExplorerPlugin::testAbiOfBinary()
     QFETCH(QString, file);
     QFETCH(QStringList, abis);
 
-    QList<ProjectExplorer::Abi> result = Abi::abisOfBinary(file);
+    QList<ProjectExplorer::Abi> result = Abi::abisOfBinary(Utils::FileName::fromString(file));
     QCOMPARE(result.count(), abis.count());
     for (int i = 0; i < abis.count(); ++i)
         QCOMPARE(result.at(i).toString(), abis.at(i));
@@ -874,7 +876,7 @@ void ProjectExplorer::ProjectExplorerPlugin::testFlavorForOs()
         foundCounter = 0;
         // make sure i is in exactly on of the flavor lists!
         foreach (const QList<Abi::OSFlavor> &l, flavorLists) {
-            QVERIFY(!l.contains(Abi::UnknownFlavor));
+            QVERIFY(l.contains(Abi::UnknownFlavor));
             if (l.contains(static_cast<Abi::OSFlavor>(i)))
                 ++foundCounter;
         }
@@ -882,4 +884,5 @@ void ProjectExplorer::ProjectExplorerPlugin::testFlavorForOs()
     }
 }
 
+
 #endif
