@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -35,8 +35,6 @@
 #include "qdeclarativecontext2d_p.h"
 #include "qdeclarativecanvastimer_p.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -67,7 +65,7 @@ public:
 
 
 public Q_SLOTS:
-    Context2D *getContext(const QString & = QString("2d"));
+    Context2D *getContext(const QString & = QLatin1String("2d"));
     void requestPaint();
 
     FillMode fillMode() const;
@@ -107,6 +105,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif //QDECLARATIVECANVAS_P_H
