@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "librarydetailscontroller.h"
 #include "ui_librarydetailswidget.h"
@@ -39,13 +36,15 @@
 #include <projectexplorer/projectexplorer.h>
 #include <projectexplorer/session.h>
 #include <projectexplorer/project.h>
+#include <projectexplorer/kitinformation.h>
 #include <projectexplorer/target.h>
 #include <projectexplorer/toolchain.h>
 #include <projectexplorer/buildconfiguration.h>
+#include <utils/hostosinfo.h>
 
-#include <QtCore/QFileInfo>
-#include <QtCore/QDir>
-#include <QtCore/QTextStream>
+#include <QFileInfo>
+#include <QDir>
+#include <QTextStream>
 
 using namespace Qt4ProjectManager;
 using namespace Qt4ProjectManager::Internal;
@@ -56,8 +55,7 @@ LibraryDetailsController::LibraryDetailsController(
     QObject(parent),
     m_platforms(AddLibraryWizard::LinuxPlatform
                 | AddLibraryWizard::MacPlatform
-                | AddLibraryWizard::WindowsPlatform
-                | AddLibraryWizard::SymbianPlatform),
+                | AddLibraryWizard::WindowsPlatform),
     m_linkageType(AddLibraryWizard::NoLinkage),
     m_macLibraryType(AddLibraryWizard::NoLibraryType),
     m_proFile(proFile),
@@ -69,30 +67,31 @@ LibraryDetailsController::LibraryDetailsController(
     m_windowsGroupVisible(true),
     m_libraryDetailsWidget(libraryDetails)
 {
-#ifdef Q_OS_MAC
-    m_creatorPlatform = CreatorMac;
-#endif
-#ifdef Q_OS_LINUX
-    m_creatorPlatform = CreatorLinux;
-#endif
-#ifdef Q_OS_WIN
-    m_creatorPlatform = CreatorWindows;
-#endif
-
-#ifndef Q_OS_LINUX
-    // project for which we are going to insert the snippet
-    const ProjectExplorer::Project *project =
-            ProjectExplorer::ProjectExplorerPlugin::instance()->session()->projectForFile(proFile);
-    // take active build configuration for it
-    Qt4BuildConfiguration *qt4BuildConfiguration =
-            qobject_cast<Qt4BuildConfiguration *>(project->activeTarget()->activeBuildConfiguration());
-    // if its tool chain is maemo behave the same as we would be on linux
-    if (qt4BuildConfiguration
-            && qt4BuildConfiguration->toolChain()
-            && (qt4BuildConfiguration->toolChain()->targetAbi().osFlavor() == ProjectExplorer::Abi::HarmattanLinuxFlavor
-                || qt4BuildConfiguration->toolChain()->targetAbi().osFlavor() == ProjectExplorer::Abi::MaemoLinuxFlavor))
+    switch (Utils::HostOsInfo::hostOs()) {
+    case Utils::HostOsInfo::HostOsMac:
+        m_creatorPlatform = CreatorMac;
+        break;
+    case Utils::HostOsInfo::HostOsLinux:
         m_creatorPlatform = CreatorLinux;
-#endif
+        break;
+    case Utils::HostOsInfo::HostOsWindows:
+        m_creatorPlatform = CreatorWindows;
+        break;
+    default:
+        break;
+    }
+
+    if (!Utils::HostOsInfo::isLinuxHost()) {
+        // project for which we are going to insert the snippet
+        const ProjectExplorer::Project *project =
+                ProjectExplorer::ProjectExplorerPlugin::instance()->session()->projectForFile(proFile);
+        // if its tool chain is maemo behave the same as we would be on linux
+        ProjectExplorer::ToolChain *tc = ProjectExplorer::ToolChainKitInformation::toolChain(project->activeTarget()->kit());
+        if (tc
+                && (tc->targetAbi().osFlavor() == ProjectExplorer::Abi::HarmattanLinuxFlavor
+                    || tc->targetAbi().osFlavor() == ProjectExplorer::Abi::MaemoLinuxFlavor))
+            m_creatorPlatform = CreatorLinux;
+    }
 
     setPlatformsVisible(true);
     setLinkageGroupVisible(true);
@@ -121,8 +120,6 @@ LibraryDetailsController::LibraryDetailsController(
             this, SLOT(slotPlatformChanged()));
     connect(m_libraryDetailsWidget->winCheckBox, SIGNAL(clicked(bool)),
             this, SLOT(slotPlatformChanged()));
-    connect(m_libraryDetailsWidget->symCheckBox, SIGNAL(clicked(bool)),
-            this, SLOT(slotPlatformChanged()));
 }
 
 LibraryDetailsController::CreatorPlatform LibraryDetailsController::creatorPlatform() const
@@ -160,8 +157,6 @@ void LibraryDetailsController::updateGui()
         m_platforms |= AddLibraryWizard::MacPlatform;
     if (libraryDetailsWidget()->winCheckBox->isChecked())
         m_platforms |= AddLibraryWizard::WindowsPlatform;
-    if (libraryDetailsWidget()->symCheckBox->isChecked())
-        m_platforms |= AddLibraryWizard::SymbianPlatform;
 
     bool macLibraryTypeUpdated = false;
     if (!m_linkageRadiosVisible) {
@@ -427,16 +422,9 @@ static QString commonScopes(AddLibraryWizard::Platforms scopes,
             str << "unix";
             if (!(common & AddLibraryWizard::MacPlatform))
                 str << ":!macx";
-            if (!(common & AddLibraryWizard::SymbianPlatform))
-                str << ":!symbian";
         } else {
             if (scopes & AddLibraryWizard::MacPlatform)
                 str << "macx";
-            if (scopes & AddLibraryWizard::MacPlatform &&
-                    scopes & AddLibraryWizard::SymbianPlatform)
-                str << "|";
-            if (scopes & AddLibraryWizard::SymbianPlatform)
-                str << "symbian";
         }
     }
     if (scopes & AddLibraryWizard::WindowsPlatform) {
@@ -470,8 +458,6 @@ static QString generateLibsSnippet(AddLibraryWizard::Platforms platforms,
         commonPlatforms &= ~QFlags<AddLibraryWizard::Platform>(AddLibraryWizard::MacPlatform);
     if (useSubfolders || addSuffix) // we will generate a separate debug/release conditions
         commonPlatforms &= ~QFlags<AddLibraryWizard::Platform>(AddLibraryWizard::WindowsPlatform);
-    if (generateLibPath) // we will generate a separate line without -L
-        commonPlatforms &= ~QFlags<AddLibraryWizard::Platform>(AddLibraryWizard::SymbianPlatform);
 
     AddLibraryWizard::Platforms diffPlatforms = platforms ^ commonPlatforms;
     AddLibraryWizard::Platforms generatedPlatforms = 0;
@@ -500,12 +486,6 @@ static QString generateLibsSnippet(AddLibraryWizard::Platforms platforms,
                     << "-framework " << libName << "\n";
         generatedPlatforms |= AddLibraryWizard::MacPlatform;
     }
-    if (diffPlatforms & AddLibraryWizard::SymbianPlatform) {
-        if (generatedPlatforms)
-            str << "else:";
-        str << "symbian: LIBS += -l" << libName << "\n";
-        generatedPlatforms |= AddLibraryWizard::SymbianPlatform;
-    }
 
     if (commonPlatforms) {
         if (generatedPlatforms)
@@ -563,8 +543,6 @@ static QString generatePreTargetDepsSnippet(AddLibraryWizard::Platforms platform
     }
     AddLibraryWizard::Platforms commonPlatforms = platforms;
     commonPlatforms &= ~QFlags<AddLibraryWizard::Platform>(AddLibraryWizard::WindowsPlatform);
-    // don't generate PRE_TARGETDEPS for symbian - relinking static lib apparently works without that
-    commonPlatforms &= ~QFlags<AddLibraryWizard::Platform>(AddLibraryWizard::SymbianPlatform);
     if (commonPlatforms) {
         if (generatedPlatforms)
             str << "else:";
@@ -1080,7 +1058,10 @@ QString InternalLibraryDetailsController::snippet() const
             ProjectExplorer::ProjectExplorerPlugin::instance()->session()->projectForFile(proFile());
 
     // the build directory of the active build configuration
-    QDir rootBuildDir(project->activeTarget()->activeBuildConfiguration()->buildDirectory());
+    QDir rootBuildDir = rootDir; // If the project is unconfigured use the project dir
+    if (ProjectExplorer::Target *t = project->activeTarget())
+        if (ProjectExplorer::BuildConfiguration *bc = t->activeBuildConfiguration())
+            rootBuildDir = bc->buildDirectory();
 
     // the project for which we insert the snippet inside build tree
     QFileInfo pfi(rootBuildDir.filePath(proRelavitePath));
