@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -53,7 +53,7 @@ SnippetEditor::SnippetEditor(SnippetEditorWidget *editor)
 
 Core::Id SnippetEditor::id() const
 {
-    return Constants::SNIPPET_EDITOR_ID;
+    return Core::Id(Constants::SNIPPET_EDITOR_ID);
 }
 
 SnippetEditorWidget::SnippetEditorWidget(QWidget *parent) : BaseTextEditorWidget(parent)
