@@ -1,59 +1,56 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "vcsbaseoutputwindow.h"
 
 #include <utils/qtcassert.h>
 #include <coreplugin/editormanager/editormanager.h>
 
-#include <QtGui/QPlainTextEdit>
-#include <QtGui/QTextCharFormat>
-#include <QtGui/QContextMenuEvent>
-#include <QtGui/QTextBlock>
-#include <QtGui/QMenu>
-#include <QtGui/QAction>
-#include <QtGui/QTextDocument>
-#include <QtGui/QTextBlockUserData>
+#include <QPlainTextEdit>
+#include <QTextCharFormat>
+#include <QContextMenuEvent>
+#include <QTextBlock>
+#include <QMenu>
+#include <QAction>
+#include <QTextDocument>
+#include <QTextBlockUserData>
 
-#include <QtCore/QPointer>
-#include <QtCore/QTextCodec>
-#include <QtCore/QDir>
-#include <QtCore/QTextStream>
-#include <QtCore/QTime>
-#include <QtCore/QPoint>
-#include <QtCore/QFileInfo>
+#include <QPointer>
+#include <QTextCodec>
+#include <QDir>
+#include <QTextStream>
+#include <QTime>
+#include <QPoint>
+#include <QFileInfo>
 
 /*!
-    \class VCSBase::VCSBaseOutputWindow
+    \class VcsBase::VcsBaseOutputWindow
 
     \brief Output window for Version Control System command and other output (Singleton).
 
@@ -67,12 +64,13 @@
     showing modified file names, allowing the user to open them.
 */
 
-namespace VCSBase {
+namespace VcsBase {
 
 namespace Internal {
 
 // Store repository along with text blocks
-class RepositoryUserData : public QTextBlockUserData    {
+class RepositoryUserData : public QTextBlockUserData
+{
 public:
     explicit RepositoryUserData(const QString &repo) : m_repository(repo) {}
     const QString &repository() const { return m_repository; }
@@ -83,7 +81,8 @@ private:
 
 // A plain text edit with a special context menu containing "Clear" and
 // and functions to append specially formatted entries.
-class OutputWindowPlainTextEdit : public QPlainTextEdit {
+class OutputWindowPlainTextEdit : public QPlainTextEdit
+{
 public:
     explicit OutputWindowPlainTextEdit(QWidget *parent = 0);
 
@@ -174,14 +173,14 @@ void OutputWindowPlainTextEdit::contextMenuEvent(QContextMenuEvent *event)
             fi = QFileInfo(repository + QLatin1Char('/') + token);
         if (fi.isFile())  {
             menu->addSeparator();
-            openAction = menu->addAction(VCSBaseOutputWindow::tr("Open \"%1\"").
+            openAction = menu->addAction(VcsBaseOutputWindow::tr("Open \"%1\"").
                                          arg(QDir::toNativeSeparators(fi.fileName())));
             openAction->setData(fi.absoluteFilePath());
         }
     }
     // Add 'clear'
     menu->addSeparator();
-    QAction *clearAction = menu->addAction(VCSBaseOutputWindow::tr("Clear"));
+    QAction *clearAction = menu->addAction(VcsBaseOutputWindow::tr("Clear"));
 
     // Run
     QAction *action = menu->exec(event->globalPos());
@@ -192,7 +191,7 @@ void OutputWindowPlainTextEdit::contextMenuEvent(QContextMenuEvent *event)
         }
         if (action == openAction) {
             const QString fileName = action->data().toString();
-            Core::EditorManager::instance()->openEditor(fileName, QString(), Core::EditorManager::ModeSwitch);
+            Core::EditorManager::openEditor(fileName, Core::Id(), Core::EditorManager::ModeSwitch);
         }
     }
     delete menu;
@@ -243,9 +242,10 @@ void OutputWindowPlainTextEdit::appendCommand(const QString &text)
 
 } // namespace Internal
 
-// ------------------- VCSBaseOutputWindowPrivate
-struct VCSBaseOutputWindowPrivate {
-    static VCSBaseOutputWindow *instance;
+// ------------------- VcsBaseOutputWindowPrivate
+struct VcsBaseOutputWindowPrivate
+{
+    static VcsBaseOutputWindow *instance;
     Internal::OutputWindowPlainTextEdit *plainTextEdit();
 
     QPointer<Internal::OutputWindowPlainTextEdit> m_plainTextEdit;
@@ -255,28 +255,28 @@ struct VCSBaseOutputWindowPrivate {
 // Create log editor on demand. Some errors might be logged
 // before CorePlugin::extensionsInitialized() pulls up the windows.
 
-Internal::OutputWindowPlainTextEdit *VCSBaseOutputWindowPrivate::plainTextEdit()
+Internal::OutputWindowPlainTextEdit *VcsBaseOutputWindowPrivate::plainTextEdit()
 {
     if (!m_plainTextEdit)
         m_plainTextEdit = new Internal::OutputWindowPlainTextEdit();
     return m_plainTextEdit;
 }
 
-VCSBaseOutputWindow *VCSBaseOutputWindowPrivate::instance = 0;
+VcsBaseOutputWindow *VcsBaseOutputWindowPrivate::instance = 0;
 
-VCSBaseOutputWindow::VCSBaseOutputWindow() :
-    d(new VCSBaseOutputWindowPrivate)
+VcsBaseOutputWindow::VcsBaseOutputWindow() :
+    d(new VcsBaseOutputWindowPrivate)
 {
-    VCSBaseOutputWindowPrivate::instance = this;
+    VcsBaseOutputWindowPrivate::instance = this;
 }
 
-VCSBaseOutputWindow::~VCSBaseOutputWindow()
+VcsBaseOutputWindow::~VcsBaseOutputWindow()
 {
-    VCSBaseOutputWindowPrivate::instance = 0;
+    VcsBaseOutputWindowPrivate::instance = 0;
     delete d;
 }
 
-QWidget *VCSBaseOutputWindow::outputWidget(QWidget *parent)
+QWidget *VcsBaseOutputWindow::outputWidget(QWidget *parent)
 {
     if (d->m_plainTextEdit) {
         if (parent != d->m_plainTextEdit->parent())
@@ -287,105 +287,104 @@ QWidget *VCSBaseOutputWindow::outputWidget(QWidget *parent)
     return d->m_plainTextEdit;
 }
 
-QWidgetList VCSBaseOutputWindow::toolBarWidgets() const
+QWidgetList VcsBaseOutputWindow::toolBarWidgets() const
 {
     return QWidgetList();
 }
 
-QString VCSBaseOutputWindow::displayName() const
+QString VcsBaseOutputWindow::displayName() const
 {
     return tr("Version Control");
 }
 
-int VCSBaseOutputWindow::priorityInStatusBar() const
+int VcsBaseOutputWindow::priorityInStatusBar() const
 {
     return -1;
 }
 
-void VCSBaseOutputWindow::clearContents()
+void VcsBaseOutputWindow::clearContents()
 {
     if (d->m_plainTextEdit)
         d->m_plainTextEdit->clear();
 }
 
-void VCSBaseOutputWindow::visibilityChanged(bool visible)
+void VcsBaseOutputWindow::visibilityChanged(bool visible)
 {
     if (visible && d->m_plainTextEdit)
         d->m_plainTextEdit->setFocus();
 }
 
-void VCSBaseOutputWindow::setFocus()
+void VcsBaseOutputWindow::setFocus()
 {
 }
 
-bool VCSBaseOutputWindow::hasFocus() const
+bool VcsBaseOutputWindow::hasFocus() const
 {
     return false;
 }
 
-bool VCSBaseOutputWindow::canFocus() const
+bool VcsBaseOutputWindow::canFocus() const
 {
     return false;
 }
 
-bool VCSBaseOutputWindow::canNavigate() const
+bool VcsBaseOutputWindow::canNavigate() const
 {
     return false;
 }
 
-bool VCSBaseOutputWindow::canNext() const
+bool VcsBaseOutputWindow::canNext() const
 {
     return false;
 }
 
-bool VCSBaseOutputWindow::canPrevious() const
+bool VcsBaseOutputWindow::canPrevious() const
 {
     return false;
 }
 
-void VCSBaseOutputWindow::goToNext()
+void VcsBaseOutputWindow::goToNext()
 {
 }
 
-void VCSBaseOutputWindow::goToPrev()
+void VcsBaseOutputWindow::goToPrev()
 {
 }
 
-void VCSBaseOutputWindow::setText(const QString &text)
+void VcsBaseOutputWindow::setText(const QString &text)
 {
     d->plainTextEdit()->setPlainText(text);
 }
 
-void VCSBaseOutputWindow::setData(const QByteArray &data)
+void VcsBaseOutputWindow::setData(const QByteArray &data)
 {
     setText(QTextCodec::codecForLocale()->toUnicode(data));
 }
 
-void VCSBaseOutputWindow::appendSilently(const QString &text)
+void VcsBaseOutputWindow::appendSilently(const QString &text)
 {
     d->plainTextEdit()->appendLines(text, d->repository);
 }
 
-void VCSBaseOutputWindow::append(const QString &text)
+void VcsBaseOutputWindow::append(const QString &text)
 {
     appendSilently(text);
-    // Pop up without focus
     if (!d->plainTextEdit()->isVisible())
-        popup(false);
+        popup(Core::IOutputPane::NoModeSwitch);
 }
 
-void VCSBaseOutputWindow::appendError(const QString &text)
+void VcsBaseOutputWindow::appendError(const QString &text)
 {
     d->plainTextEdit()->appendError(text);
     if (!d->plainTextEdit()->isVisible())
-        popup(false); // Pop up without focus
+        popup(Core::IOutputPane::NoModeSwitch);
 }
 
-void VCSBaseOutputWindow::appendWarning(const QString &text)
+void VcsBaseOutputWindow::appendWarning(const QString &text)
 {
     d->plainTextEdit()->appendWarning(text);
     if (!d->plainTextEdit()->isVisible())
-        popup(false); // Pop up without focus
+        popup(Core::IOutputPane::NoModeSwitch);
 }
 
 // Helper to format arguments for log windows hiding common password
@@ -411,7 +410,7 @@ static inline QString formatArguments(const QStringList &args)
     return rc;
 }
 
-QString VCSBaseOutputWindow::msgExecutionLogEntry(const QString &workingDir,
+QString VcsBaseOutputWindow::msgExecutionLogEntry(const QString &workingDir,
                                                   const QString &executable,
                                                   const QStringList &arguments)
 {
@@ -423,12 +422,12 @@ QString VCSBaseOutputWindow::msgExecutionLogEntry(const QString &workingDir,
             arg(QDir::toNativeSeparators(workingDir), nativeExecutable, args);
 }
 
-void VCSBaseOutputWindow::appendCommand(const QString &text)
+void VcsBaseOutputWindow::appendCommand(const QString &text)
 {
     d->plainTextEdit()->appendCommand(text);
 }
 
-void VCSBaseOutputWindow::appendCommand(const QString &workingDirectory,
+void VcsBaseOutputWindow::appendCommand(const QString &workingDirectory,
                                         const QString &binary,
                                         const QStringList &args)
 {
@@ -436,40 +435,40 @@ void VCSBaseOutputWindow::appendCommand(const QString &workingDirectory,
 }
 
 
-void VCSBaseOutputWindow::appendData(const QByteArray &data)
+void VcsBaseOutputWindow::appendData(const QByteArray &data)
 {
     appendDataSilently(data);
     if (!d->plainTextEdit()->isVisible())
-        popup(false); // Pop up without focus
+        popup(Core::IOutputPane::NoModeSwitch);
 }
 
-void VCSBaseOutputWindow::appendDataSilently(const QByteArray &data)
+void VcsBaseOutputWindow::appendDataSilently(const QByteArray &data)
 {
     appendSilently(QTextCodec::codecForLocale()->toUnicode(data));
 }
 
-VCSBaseOutputWindow *VCSBaseOutputWindow::instance()
+VcsBaseOutputWindow *VcsBaseOutputWindow::instance()
 {
-    if (!VCSBaseOutputWindowPrivate::instance) {
-        VCSBaseOutputWindow *w = new VCSBaseOutputWindow;
+    if (!VcsBaseOutputWindowPrivate::instance) {
+        VcsBaseOutputWindow *w = new VcsBaseOutputWindow;
         Q_UNUSED(w)
     }
-    return VCSBaseOutputWindowPrivate::instance;
+    return VcsBaseOutputWindowPrivate::instance;
 }
 
-QString VCSBaseOutputWindow::repository() const
+QString VcsBaseOutputWindow::repository() const
 {
     return d->repository;
 }
 
-void VCSBaseOutputWindow::setRepository(const QString &r)
+void VcsBaseOutputWindow::setRepository(const QString &r)
 {
     d->repository = r;
 }
 
-void VCSBaseOutputWindow::clearRepository()
+void VcsBaseOutputWindow::clearRepository()
 {
     d->repository.clear();
 }
 
-} // namespace VCSBase
+} // namespace VcsBase
