@@ -1,3 +1,4 @@
+import __builtin__
 
 # appends to line, by typing <typeWhat> after <insertAfterLine> text into <codeArea> widget
 def appendToLine(codeArea, insertAfterLine, typeWhat):
@@ -18,11 +19,9 @@ def checkSyntaxError(issuesView, expectedTextsArray, warnIfMoreIssues = True):
     if(warnIfMoreIssues and issuesModel.rowCount() > 1):
         test.warning("More than one expected issues reported")
     # iterate issues and check if there exists "Unexpected token" message
-    for row in range(issuesModel.rowCount()):
+    for description, type in zip(dumpItems(issuesModel, role=Qt.UserRole + 3),
+                                 dumpItems(issuesModel, role=Qt.UserRole + 5)):
         # enum Roles { File = Qt::UserRole, Line, MovedLine, Description, FileNotFound, Type, Category, Icon, Task_t };
-        index = issuesModel.index(row, 0)
-        description = str(index.data(Qt.UserRole + 3).toString())
-        type = str(index.data(Qt.UserRole + 5).toString())
         # check if at least one of expected texts found in issue text
         for expectedText in expectedTextsArray:
             if expectedText in description:
@@ -34,13 +33,6 @@ def checkSyntaxError(issuesView, expectedTextsArray, warnIfMoreIssues = True):
                     return True
     return False
 
-# wait and verify if object exists/not exists
-def checkIfObjectExists(name, shouldExist = True, timeout = 3000, verboseOnFail = False):
-    result = waitFor("object.exists(name) == shouldExist", timeout)
-    if verboseOnFail and not result:
-        test.log("checkIfObjectExists() failed for '%s'" % name)
-    return result
-
 # change autocomplete options to manual
 def changeAutocompleteToManual():
     invokeMenuItem("Tools", "Options...")
@@ -50,3 +42,23 @@ def changeAutocompleteToManual():
     selectFromCombo(":Behavior.completionTrigger_QComboBox", "Manually")
     verifyEnabled(":Options.OK_QPushButton")
     clickButton(waitForObject(":Options.OK_QPushButton"))
+
+# wait and verify if object item exists/not exists
+def checkIfObjectItemExists(object, item, timeout = 3000):
+    try:
+        waitForObjectItem(object, item, timeout)
+        return True
+    except:
+        return False
+
+# this function creates a string holding the real name of a Qml Item
+# param type defines the Qml type (support is limited)
+# param container defines the container of the Qml item - can be a real or symbolic name
+# param clip defines the state of the clip property (true/false)
+# param text a string holding the complete text property (e.g. "text='example'", "text~='ex.*'")
+def getQmlItem(type, container, clip, text=""):
+    if (container.startswith(":")):
+        container = "'%s'" % container
+    clip = ("%s" % __builtin__.bool(clip)).lower()
+    return ("{clip='%s' container=%s enabled='true' %s type='%s' unnamed='1' visible='true'}"
+            % (clip, container, text, type))
\ No newline at end of file
